import { DocumentHandle, DocumentStatus, GlossaryLanguagePair, Language, TextResult, Usage, GlossaryInfo, WriteResult, MultilingualGlossaryInfo, MultilingualGlossaryDictionaryInfo, MultilingualGlossaryDictionaryEntries, MultilingualGlossaryDictionaryApiResponse, MultilingualGlossaryDictionaryEntriesApiResponse, ListMultilingualGlossaryApiResponse } from './types';
/**
 * Parses the given multilingual glossary info API response to a GlossaryInfo object.
 * @private
 */
export declare function parseMultilingualGlossaryDictionaryInfo(obj: MultilingualGlossaryDictionaryApiResponse): MultilingualGlossaryDictionaryInfo;
/**
 * Parses the given multilingual glossary entries API response to a GlossaryDictionaryEntries object.
 * @private
 */
export declare function parseMultilingualGlossaryDictionaryEntries(obj: MultilingualGlossaryDictionaryEntriesApiResponse): MultilingualGlossaryDictionaryEntries[];
/**
 * Parses the given list multilingual glossaries API response.
 * @private
 */
export declare function parseListMultilingualGlossaries(obj: ListMultilingualGlossaryApiResponse): MultilingualGlossaryInfo[];
/**
 * Parses the given JSON string to a GlossaryInfo object.
 * @private
 */
export declare function parseGlossaryInfo(json: string): GlossaryInfo;
/**
 * Parses the given JSON string to a MultilingualGlossaryInfo object.
 * @private
 */
export declare function parseMultilingualGlossaryInfo(json: string): MultilingualGlossaryInfo;
/**
 * Parses the given JSON string to an array of GlossaryInfo objects.
 * @private
 */
export declare function parseGlossaryInfoList(json: string): GlossaryInfo[];
/**
 * Parses the given JSON string to a DocumentStatus object.
 * @private
 */
export declare function parseDocumentStatus(json: string): DocumentStatus;
/**
 * Parses the given JSON string to a Usage object.
 * @private
 */
export declare function parseUsage(json: string): Usage;
/**
 * Parses the given JSON string to an array of TextResult objects.
 * @private
 */
export declare function parseTextResultArray(json: string): TextResult[];
export declare function parseWriteResultArray(json: string): WriteResult[];
/**
 * Parses the given JSON string to an array of Language objects.
 * @private
 */
export declare function parseLanguageArray(json: string): Language[];
/**
 * Parses the given JSON string to an array of GlossaryLanguagePair objects.
 * @private
 */
export declare function parseGlossaryLanguagePairArray(json: string): GlossaryLanguagePair[];
/**
 * Parses the given JSON string to a DocumentHandle object.
 * @private
 */
export declare function parseDocumentHandle(json: string): DocumentHandle;
